pub trait PoolTypeTrait: Send + Sync {
// Required method
fn pool_type(&self) -> PoolType;
}Expand description
Interface for pool operations, implemented by all pool types (V2, V3, etc.)
pub trait PoolTypeTrait: Send + Sync {
// Required method
fn pool_type(&self) -> PoolType;
}Interface for pool operations, implemented by all pool types (V2, V3, etc.)