pub trait BitMath {
// Required methods
fn most_significant_bit(self) -> usize;
fn least_significant_bit(self) -> usize;
}Expand description
Trait to associate bit math functions with Uint types.
pub trait BitMath {
// Required methods
fn most_significant_bit(self) -> usize;
fn least_significant_bit(self) -> usize;
}Trait to associate bit math functions with Uint types.